@@ -56,7 +56,7 @@ sub get_pattern {
         '%P'  => {  name => 'pid',
                     code => \&_get_pid },
         '%H'  => {  name => 'hostname',
-                    code => \&Sys::Hostname::hostname },
+                    code => sub { Sys::Hostname::hostname() } },
         '%N'  => {  name => 'newline',
                     code => sub { "\n" } },
         '%S'  => {  name => 'progname',
